#!/bin/ksh
#> This script will install patch EricIMS
#> patch: 4.0.1.0.10.1
#

# variables used after <productVersion> and <wsVersion> drop.
export NEPATCH_START_DIR=`pwd`
export ARCHIVE_DIR=$NEPATCH_START_DIR/Archive
export BACKUP_DIR=$NEPATCH_START_DIR/Backup

########################################################
# Check system values required for this module but not checked by the
# main installer.
if [[ -z $FLEXPM_HOME ]]; then
  echo "+> FLEXPM_HOME environment is not defined"
  echo "+> Please ensure that this is defined and then reinstall upgrade"
  echo ""
  exit 2
fi

if [[ ! -d $FLEXPM_HOME ]]; then
  echo "+> FLEXPM_HOME environment value '$FLEXPM_HOME'"
  echo "+> is not a valid directory. Please check this value"
  echo ""
  exit 2
fi

# Begin the upgrade
########################################################
# Check system values required for this module but not checked by the
# main installer.
if [[ -z $EricIMS_HOME ]]; then
  echo "+> EricIMS_HOME environment is not defined"
  echo "+> Please ensure that this is defined and then reinstall upgrade"
  echo ""
  exit 2
fi

if [[ ! -d $EricIMS_HOME ]]; then
  echo "+> EricIMS_HOME environment value '$EricIMS_HOME'"
  echo "+> is not a valid directory. Please check this value"
  echo ""
  exit 2
fi

# Begin the upgrade
echo "+ Installing EricIMS component upgrades ... "
date +"+ Component upgrade is started at %T, %D ... "

cd ${NEPATCH_START_DIR}
if [ ! -d $BACKUP_DIR ]
then
  mkdir $BACKUP_DIR
fi

echo ""
echo "+ Backing up original EricIMS module files ..."
cd $EricIMS_HOME
for file in `gtar -tzf ${NEPATCH_START_DIR}/EricIMS_1.0.tgz`
do
  if [ -f $file ]
  then
    if [ ! -d ${ARCHIVE_DIR}/`dirname $file` ]
    then
      mkdir -p ${ARCHIVE_DIR}/`dirname $file`
    fi
    cp $file ${ARCHIVE_DIR}/`dirname $file`
    chmod +w $file
  fi
done

cd $NEPATCH_START_DIR/Archive
gtar -czf ../Module_Archive_`date '+%y%m%d_%H%M%S'`.tar.gz *
cd $NEPATCH_START_DIR
rm -rf ${ARCHIVE_DIR}
mv -f Module_Archive*.tar.gz $BACKUP_DIR/
cd $EricIMS_HOME

echo "+ Installing new/updated files for EricIMS module ..."
gtar -xvzf ${NEPATCH_START_DIR}/EricIMS_1.0.tgz

cd $EricIMS_HOME/vendor/Ericsson/IMS/1.3/EricIMS_loader/IMS_XML/config
rm LoaderControl.txt DatabaseTable.txt DatabaseFile.txt
make control
make dbtable
make dbfile

cd $EricIMS_HOME/vendor/Ericsson/IMS/1.3/EricIMS_loader/IMS_EMA/config
rm LoaderControl.txt DatabaseTable.txt DatabaseFile.txt
make control
make dbtable
make dbfile

cd $EricIMS_HOME/vendor/Ericsson/IMS/1.3/scripts
chmod ugo+x file_decode.pl

date +"+ EricIMS component upgrade is completed at %T, %D ....."
echo ""
exit 0
$
